@@ -10,7 +10,7 @@ use base qw(Module::Patch);
 
 use Data::Dumper::Perltidy;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 our %config;
 
@@ -38,17 +38,19 @@ sub patch_data {
 1;
 # ABSTRACT: Use Data::Dumper::Perltidy
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Log::Any::Adapter::Core::Patch::UseDataDumperPerltidy - Use Data::Dumper::Perltidy
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -77,16 +79,31 @@ L<Log::Any::Adapter::Core::Patch::SetDumperIndent>
 
 L<Log::Any::Adapter::Core::Patch::UseDataDump>
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Log-Any-Adapter-Core-Patch-UseDataDumperPerltidy>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Log-Any-Adapter-Core-Patch-UseDataDumperPerltidy>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Log-Any-Adapter-Core-Patch-UseDataDumperPerltidy>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2013 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
